<a href="https://www.islas.org.mx/"><img src="https://www.islas.org.mx/img/logo.svg" align="right" width="256" /></a>
# Referee Cat Recognition
[![codecov](https://codecov.io/gh/IslasGECI/referee_cat_recognition/graph/badge.svg?token=jwyIdQ5E2I)](https://codecov.io/gh/IslasGECI/referee_cat_recognition)
![licencia](https://img.shields.io/github/license/IslasGECI/referee_cat_recognition)
![languages](https://img.shields.io/github/languages/top/IslasGECI/referee_cat_recognition)
![commits](https://img.shields.io/github/commit-activity/y/IslasGECI/referee_cat_recognition)
![PyPI - Version](https://img.shields.io/pypi/v/referee_cat_recognition)

Para usar este repo como plantilla debemos hacer lo siguiente:

1. Presiona el botón verde que dice _Use this template_
1. Selecciona como dueño a la organización IslasGECI
1. Agrega el nombre del nuevo módulo de python
1. Presiona el botón _Create repository from template_
1. Reemplaza `referee_cat_recognition` por el nombre del nuevo módulo en:
    - `Makefile`
    - `pyproject.toml`
    - `tests\test_transformations.py`
1. Renombra el archivo `referee_cat_recognition\transformations.py` al nombre del primer archivo del
   nuevo módulo
1. Cambia la descripción del archivo `referee_cat_recognition\__init__.py`
1. Renombra el directorio `referee_cat_recognition` al nombre del nuevo módulo
1. Cambia el `codecov_token` del archivo `Makefile`

Los archivos del nuevo módulo los agregarás en la carpeta que antes se llamaba
`referee_cat_recognition` y las pruebas en la carpeta `tests`.
